@@ -80,7 +80,7 @@ def reset_keys(request):
 def register(request,
              email_template='locksmith/registration_email.txt',
              registration_template=getattr(settings, 'LOCKSMITH_REGISTER_TEMPLATE', 'locksmith/register.html'),
-             registered_template='locksmith/registered.html',
+             registered_template=getattr(settings, 'LOCKSMITH_REGISTERED_TEMPLATE', 'locksmith/registered.html'),
             ):
     '''
         API registration view
